@@ -6,6 +6,7 @@ from dataclasses import dataclass
 
 from typhoon.core.cron_utils import aws_schedule_to_cron
 from typhoon.core.dags import DAGDefinitionV2, TaskDefinition
+from typhoon.core.glue import load_component
 from typhoon.core.templated import Templated
 from typhoon.core.transpiler.transpiler_helpers import ImportsTemplate, extract_dependencies, camel_case, extract_imports, render_dependencies, \
     is_component_task, render_args
@@ -63,11 +64,13 @@ class AirflowDagFile(Templated):
             # if self.source == '{{ task.input }}':
             args = {}
             {{ task.args | render_args | indent(8, False) }}
+            {{ task | default_args_not_set | render_args | indent(8, False) }}
             return args
             # assert False, 'Compiler error'
             {% else %}
             args = {}
             {{ task.args | render_args | indent(8, False) }}
+            {{ task | default_args_not_set | render_args | indent(8, False) }}
             return args
             {% endif %}
     
@@ -161,3 +164,15 @@ class AirflowDagFile(Templated):
     @property
     def component_tasks(self) -> Dict[str, TaskDefinition]:
         return {k: v for k, v in self.dag.tasks.items() if v.component is not None}
+    
+    @staticmethod
+    def default_args_not_set(component_task: TaskDefinition) -> Dict[str, Any]:
+        kind, component_name = component_task.component.split('.')
+        if kind == 'components':
+            kind = 'custom'
+        component = load_component(component_name, kind=kind)
+        return {
+            arg: val.default
+            for arg, val in component.args.items()
+            if arg not in component_task.args
+        }
